package Data::Object::Func::Hash;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Hash

=cut

=head1 ABSTRACT

Functions for HashRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Hash;

=cut

=head1 DESCRIPTION

Data::Object::Func::Hash is an abstract base class for function classes in the
Data::Object::Func::Hash space.

=cut
